==> LPDS-0.01.tar.gz: LPDS-0.01/lib/LPDS.pm <==
package LPDS;

use 5.006;
use strict;
use warnings;

=head1 NAME

LPDS - The great new LPDS!

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';


=head1 SYNOPSIS

Quick summary of what the module does.

Perhaps a little code snippet.

    use LPDS;

    my $foo = LPDS->new();
    ...

=head1 EXPORT

A list of functions that can be exported.  You can delete this section
if you don't export anything, such as for a purely object-oriented module.

=head1 SUBROUTINES/METHODS

=cut



=head1 AUTHOR

"Xi Yang", C<< <"yangx at im.ac.cn"> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-lpds at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=LPDS>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc LPDS


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=LPDS>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/LPDS>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/LPDS>

=item * Search CPAN

L<http://search.cpan.org/dist/LPDS/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2012 "Xi Yang".

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of LPDS

==> LPDS-0.02.tar.gz: LPDS-0.02/lib/LPDS.pm <==
package LPDS;

use 5.006;
use strict;
use warnings;

=head1 NAME

LPDS - Help you decide a laptop

=head1 VERSION

Version 0.02

=cut

our $VERSION = '0.02';


=head1 SYNOPSIS

Just run it:

 perl LPDS.pl

=head1 DESCRIPTION

This is a GUI software which lists hardwares of different laptops in a table, and compare laptop hardwares using graph.
It might provide you some help to decide which laptop to buy.

=head1 AUTHOR

"Xi Yang", C<< <"yangx at im.ac.cn"> >>

=head1 BUGS

Please report any bugs or feature requests to C<bug-lpds at rt.cpan.org>, or through
the web interface at L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=LPDS>.  I will be notified, and then you'll
automatically be notified of progress on your bug as I make changes.




=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc LPDS


You can also look for information at:

=over 4

=item * RT: CPAN's request tracker (report bugs here)

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=LPDS>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/LPDS>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/LPDS>

=item * Search CPAN

L<http://search.cpan.org/dist/LPDS/>

=back


=head1 ACKNOWLEDGEMENTS


=head1 LICENSE AND COPYRIGHT

Copyright 2012 "Xi Yang".

This program is free software; you can redistribute it and/or modify it
under the terms of either: the GNU General Public License as published
by the Free Software Foundation; or the Artistic License.

See http://dev.perl.org/licenses/ for more information.


=cut

1; # End of LPDS
